@@ -15,11 +15,17 @@ if IPython.__version__ > '0.10.2':
     try:
         get_ipython
     except NameError:
-        from IPython.frontend.terminal.embed import InteractiveShellEmbed    
+        from IPython.frontend.terminal.embed import InteractiveShellEmbed
         ipshell = InteractiveShellEmbed()
         def_colors = ipshell.colors
-    else:  
+    else:
         def_colors = get_ipython.im_self.colors
+
+    from IPython.utils import io
+
+    def update_stdout():
+        # setup stdout to ensure output is available with nose
+        io.stdout = sys.stdout = sys.__stdout__
 else:
     from IPython.Debugger import Pdb, BdbQuit_excepthook
     from IPython.Shell import IPShell
@@ -30,8 +36,16 @@ else:
         IPShell(argv=[''])
         ip = ipapi.get()
     def_colors = ip.options.colors
-                
+
+    from IPython.Shell import Term
+
+    def update_stdout():
+        # setup stdout to ensure output is available with nose
+        Term.cout = sys.stdout = sys.__stdout__
+
+
 def set_trace(frame=None):
+    update_stdout()
     BdbQuit_excepthook.excepthook_ori = sys.excepthook
     sys.excepthook = BdbQuit_excepthook
     if frame is None:
@@ -40,6 +54,7 @@ def set_trace(frame=None):
 
 
 def post_mortem(tb):
+    update_stdout()
     BdbQuit_excepthook.excepthook_ori = sys.excepthook
     sys.excepthook = BdbQuit_excepthook
     p = Pdb(def_colors)
